<?php

/**
 * @file
 * Contains \Drupal\paynl_payment\Controller\Exchange.
 */

namespace Drupal\paynl_payment\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Drupal\payment\Entity\PaymentInterface;
use Drupal\paynl_payment\Entity\PaynlProfile;
use Paynl\Config;
use Paynl\Transaction;

/**
 * Handles the "exchange" route.
 */
class Exchange extends ControllerBase {

  /**
   * Pay.nl calls this after the payment status has been changed. We can use the Transaction wrapper to retrieve
   * the transaction status.
   *
   * @param \Drupal\payment\Entity\PaymentInterface $payment
   *
   * @return
   */
  public function execute(PaymentInterface $payment) {
    // Get the Pay.nl profile.
    $paynl_profile = $payment->getPaymentMethod()->getProfile();

    // Configure API.
    $api_key = $paynl_profile->getApiKey();
    $service_id = $paynl_profile->getServiceId();
    Config::setApiToken($api_key);
    Config::setServiceId($service_id);

    // Change status of payment based on transaction status.
    $transaction = Transaction::getForExchange();

    // Payment status mapping.
    $payment_status = ($transaction->isPaid())
        ? 'payment_success' : (($transaction->isCanceled())
            ? 'payment_cancelled' : 'payment_pending');

    // Update payment status.
    $payment->getPaymentMethod()->updatePaymentStatus($payment, $payment_status);

    return new Response();
  }

}
