<?php

/**
 * @file
 * Definition of Drupal\paynl_payment\Entity\PaynlProfile.
 */

namespace Drupal\paynl_payment\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Entity\EntityManagerInterface;

/**
 * Defines a Pay.nl profile entity.
 *
 * @ConfigEntityType(
 *   admin_permission = "administer paynl payment",
 *   handlers = {
 *     "access" = "\Drupal\Core\Entity\EntityAccessControlHandler",
 *     "form" = {
 *       "default" = "Drupal\paynl_payment\Entity\PaynlProfile\PaynlProfileForm",
 *       "delete" = "Drupal\paynl_payment\Entity\PaynlProfile\PaynlProfileDeleteForm"
 *     },
 *     "list_builder" = "Drupal\paynl_payment\Entity\PaynlProfile\PaynlProfileListBuilder",
 *     "storage" = "\Drupal\Core\Config\Entity\ConfigEntityStorage"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "apiKey" = "apiKey",
 *     "serviceId" = "serviceId"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "apiKey",
 *     "serviceId",
 *     "testMode",
 *     "uuid"
 *   },
 *   id = "paynl_profile",
 *   label = @Translation("Pay.nl Profile"),
 *   links = {
 *     "canonical" = "/admin/config/services/payment/paynl/profiles/edit/{paynl_profile}",
 *     "collection" = "/admin/config/services/payment/paynl/profiles",
 *     "edit-form" = "/admin/config/services/payment/paynl/profiles/edit/{paynl_profile}",
 *     "delete-form" = "/admin/config/services/payment/paynl/profiles/edit/{paynl_profile}/delete"
 *   }
 * )
 */
class PaynlProfile extends ConfigEntityBase implements PaynlProfileInterface {

  /**
   * The entity manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $entityManager;

  /**
   * The entity's unique machine name.
   *
   * @var string
   */
  public $id;

  /**
   * The human-readable name.
   *
   * @var string
   */
  protected $label;

  /**
   * The Pay.nl API key for this profile.
   *
   * @var string
   */
  protected $apiKey;

  /**
   * The Pay.nl service id for this profile.
   *
   * @var string
   */
  protected $serviceId;

  /**
   * Whether this profile is operating in test mode.
   *
   * @var string
   */
  protected $testMode;

  /**
   * The typed config manager.
   *
   * @var \Drupal\Core\Config\TypedConfigManagerInterface
   */
  protected $typedConfigManager;

  /**
   * The entity's UUID.
   *
   * @var string
   */
  public $uuid;

  /**
   * {@inheritdoc}
   */
  public function setId($id) {
    $this->id = $id;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setLabel($label) {
    $this->label = $label;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setApiKey($apiKey) {
    $this->apiKey = $apiKey;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getApiKey() {
    return $this->apiKey;
  }

  /**
   * {@inheritdoc}
   */
  public function setServiceId($serviceId) {
    $this->serviceId = $serviceId;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getServiceId() {
    return $this->serviceId;
  }

  /**
   * {@inheritdoc}
   */
  public function setTestMode($testMode) {
    $this->testMode = $testMode;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function hasTestMode() {
    return $this->testMode;
  }

  /**
   * Sets the entity manager.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
   *
   * @return $this
   */
  public function setEntityManager(EntityManagerInterface $entity_manager) {
    $this->entityManager = $entity_manager;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  protected function entityManager() {
    if (!$this->entityManager) {
      $this->entityManager = parent::entityManager();
    }

    return $this->entityManager;
  }

  /**
   * Sets the typed config.
   *
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typed_config_manager
   *
   * @return $this
   */
  public function setTypedConfig(TypedConfigManagerInterface $typed_config_manager) {
    $this->typedConfigManager = $typed_config_manager;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  protected function getTypedConfig() {
    if (!$this->typedConfigManager) {
      $this->typedConfigManager = parent::getTypedConfig();
    }

    return $this->typedConfigManager;
  }

}
