<?php

/**
 * @file
 * Contains \Drupal\paynl_payment\Form\TestForm.
 */

namespace Drupal\paynl_payment\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\paynl_payment\Entity\PaynlProfile;
use Paynl\Config;
use Paynl\Paymentmethods;

/**
 * Defines a form to configure maintenance settings for this site.
 */
class TestForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'paynl_payment_test';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $paynl_profiles = PaynlProfile::loadMultiple();

    $options = array('' => t('- Select a profile -'));
    foreach($paynl_profiles as $id => $paynl_profile) {
      $options[$paynl_profile->getApiKey().'|'.$paynl_profile->getServiceId()] = $paynl_profile->label();
    }

    $form['profile'] = array(
      '#title' => t('Pay.nl profile'),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => '',
    );

    $form['actions'] = array(
      'submit' => array(
        '#type' => 'submit',
        '#value' => t('Test'),
      )
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   *
   * @todo Proper exception handling. Plural messages.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $profile = explode('|', $form_state->getValue('profile'));

    if (empty($profile)) {
      drupal_set_message(t('You need to select a profile to test.'), 'error');
      return;
    }

    try {
      // Configure API.
      $api_key = $profile[0];
      $service_id = $profile[1];
      Config::setApiToken($api_key);
      Config::setServiceId($service_id);

      try {
        // Get the Pay.nl payment methods.
        $methods = Paymentmethods::getList();

        if (!$methods) {
          drupal_set_message(t('Could not retrieve a list of payment methods. The API key for the selected profile might be invalid.'),
            'warning');
          return;
        }

        $names = array();
        foreach ($methods as $method) {
          $names[] = $method['name'];
        }

        drupal_set_message(t('Found @count payment methods: @methods. Connection for the selected profile is working.', array(
          '@count' => count($names),
          '@methods' => implode(', ', $names),
        )), 'status');
      } catch (\Exception $e) {
        drupal_set_message($e->getMessage(), 'error');
        return;
      }
    } catch (\Exception $e) {
      drupal_set_message($e->getMessage(), 'error');
      return;
    }
  }
}

?>